__name__    = "easyros"
__version__ = "0.0.8"
__author__   = "yourmoln"
__author_email__ = "yourmoln@outlook.com"
__url__     = "https://github.com/yourmoln/easyros"
__description__ = "ros的安装与开发工具"
__license__ = "Apache 2.0"
__copyright__ = 'Copyright yourmoln'
